# A collection of `ezs` basics functions.

This package cannot be used alone. [ezs](https://www.npmjs.com/package/ezs) has to be installed

## Usage

```js
import ezs from 'ezs';
import ezsBasics from 'ezs-basics';

ezs.use(ezsBasics);

process.stdin
    .pipe(ezs('STATEMENT_NAME', { STATEMENT_PARAMETERS })
    .pipe(process.stdout);
```

# Statements

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### Table of Contents

-   [BUFObject](#bufobject)
    -   [Parameters](#parameters)
-   [CSVObject](#csvobject)
    -   [Parameters](#parameters-1)
-   [CSVParse](#csvparse)
    -   [Parameters](#parameters-2)
-   [CSVString](#csvstring)
    -   [Parameters](#parameters-3)
-   [JSONParse](#jsonparse)
    -   [Parameters](#parameters-4)
-   [JSONString](#jsonstring)
    -   [Parameters](#parameters-5)
-   [OBJCount](#objcount)
    -   [Parameters](#parameters-6)
-   [OBJFlatten](#objflatten)
    -   [Parameters](#parameters-7)
-   [OBJStandardize](#objstandardize)
    -   [Parameters](#parameters-8)
-   [SKOSObject](#skosobject)
    -   [Parameters](#parameters-9)
-   [TXTConcat](#txtconcat)
    -   [Parameters](#parameters-10)
-   [TXTObject](#txtobject)
    -   [Parameters](#parameters-11)
-   [TXTParse](#txtparse)
    -   [Parameters](#parameters-12)
-   [TXTZip](#txtzip)
-   [URLFetch](#urlfetch)
    -   [Parameters](#parameters-13)
-   [URLParse](#urlparse)
-   [URLStream](#urlstream)
    -   [Parameters](#parameters-14)
-   [URLString](#urlstring)
-   [XMLParse](#xmlparse)
    -   [Parameters](#parameters-15)
-   [XMLString](#xmlstring)
    -   [Parameters](#parameters-16)

## BUFObject

Take `Mixed` and produce Buffer.
For example, it's useful to send string to browser.

### Parameters

-   `none` **[undefined](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/undefined)** 

Returns **[Buffer](https://nodejs.org/api/buffer.html)** 

## CSVObject

Take `Array` and transform rows into object.
Each row (Array) is tranformed
into a object where keys are the value of the first row

### Parameters

-   `none` **[undefined](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/undefined)** 

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## CSVParse

-   **See: <https://github.com/Inist-CNRS/node-csv-string>**

Take `String` and parse CSV  to generate object

### Parameters

-   `separator` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** to indicate the CSV separator (optional, default `auto`)
-   `quote` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** to indicate the CSV quote. (optional, default `auto`)

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## CSVString

Take `Object` and transform row  into string
where each field is separated with a character

### Parameters

-   `format` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** if set to "strict" the fields will wrapped with double quote (optional, default `standard`)
-   `separator` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** to indicate the CSV separator (optional, default `;`)
-   `header` **[Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** first line contains key name (optional, default `true`)

Returns **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** 

## JSONParse

-   **See: <https://github.com/dominictarr/JSONStream>**

Take `String` and parse JSON and generate objects

### Parameters

-   `separator` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** to split at every JSONPath found (optional, default `*`)

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## JSONString

Take `Object` and generate JSON

### Parameters

-   `wrap` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** every document are wrapped into an array (optional, default `true`)
-   `indent` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** indent JSON (optional, default `false`)

Returns **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** 

## OBJCount

Take `Object` and count how many objects are received and sent the total

### Parameters

-   `none` **[undefined](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/undefined)** 

Returns **[Number](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Number)** 

## OBJFlatten

-   **See: <https://www.npmjs.com/package/flat>**

Take `Object` and flat it with delimited character.

### Parameters

-   `separator` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** choose a character for  flatten keys (optional, default `/`)
-   `safe` **[Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** preserve arrays and their contents, (optional, default `false`)

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## OBJStandardize

Take `Object` and standardize it so each object will have the sames keys

### Parameters

-   `none` **[undefined](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/undefined)** 

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## SKOSObject

Take `Object` generated by XMLMapping & SKOS data and
create a new basic object with only keys & values

### Parameters

-   `none` **[undefined](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/undefined)** 

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## TXTConcat

Take `String` and concat all items in just one string

### Parameters

-   `none` **[undefined](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/undefined)** 

Returns **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** 

## TXTObject

Take `String` and generate an object with a key and a value, where the value is the input string.

### Parameters

-   `key` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** choose a the key name (optional, default `value`)

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## TXTParse

Take `String` and split at each separator found

### Parameters

-   `separtor` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** choose character which trigger the split (optional, default `\n`)

Returns **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** 

## TXTZip

Take a String and zip it

Returns **[Buffer](https://nodejs.org/api/buffer.html)** 

## URLFetch

Take `Object` and create a new field with the content of URL.
Or if no target will be specified, the output will be the content of URL

### Parameters

-   `url` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** URL to fecth
-   `target` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** choose the key to set
-   `json` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** Pasre as JSON the content of URL (optional, default `false`)

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## URLParse

Take `String` of URL, parse it and returns `Object`

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## URLStream

Take `Object` as parameters of URL, throw each chunk from the result

### Parameters

-   `url` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** URL to fecth
-   `target` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** choose the key to set
-   `json` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** Pasre as JSON the content of URL (optional, default `false`)

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## URLString

Take `Object` representing a URL and stringify it

Returns **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** 

## XMLParse

-   **See: <https://www.npmjs.com/package/xml-splitter>**

Take `String` as XML input, parse it and split it in multi document at each path found

### Parameters

-   `url` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** URL to fecth
-   `target` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)?** choose the key to set
-   `separator` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** choose a character for flatten keys (optional, default `/`)

Returns **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** 

## XMLString

Take `Object` and transform it into a XML string

### Parameters

-   `rootElement` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** Root element name for the tag which start and close the feed (optional, default `items`)
-   `contentElement` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** Content element name for the tag which start and close each item (optional, default `item`)

Returns **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** 
