'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
function CSVObject(data, feed) {
    var _this = this;

    if (this.isLast()) {
        return feed.close();
    }

    if (!this.columns) {
        this.columns = data.map(function (name) {
            return name.replace(/\./g, '');
        });

        var countCols = {};
        var renamedCols = {};
        this.columns.forEach(function (colname) {
            countCols[colname] = !countCols[colname] ? 1 : countCols[colname] + 1;
        });
        this.columns = this.columns.map(function (colname) {
            if (countCols[colname] > 1) {
                renamedCols[colname] = !renamedCols[colname] ? 1 : renamedCols[colname] + 1;
                return colname + renamedCols[colname];
            }
            return colname;
        });
        return feed.end();
    }

    if (Array.isArray(data)) {
        var obj = {};
        data.forEach(function (item, index) {
            var columnName = _this.columns[index] ? _this.columns[index].trim() : 'Column #'.concat(index);
            obj[columnName] = item;
        });
        return feed.send(obj);
    }

    feed.end();
}

/**
 * Take `Array` and transform rows into object.
 * Each row (Array) is tranformed
 * into a object where keys are the value of the first row
 *
 * @name CSVObject
 * @param {undefined} none
 * @returns {Object}
 */
exports.default = {
    CSVObject: CSVObject
};