'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _csvString = require('csv-string');

var _csvString2 = _interopRequireDefault(_csvString);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function strict(data, sep) {
    var q = new RegExp('"', 'g');
    var line = '';
    var s = '';
    Object.keys(data).forEach(function (key) {
        line = line.concat(s.concat('"').concat(String(data[key]).replace(q, '""')).concat('"'));
        s = sep;
    });
    return line.concat('\r\n');
}

function CSVString(data, feed) {
    var format = String(this.getParam('format', 'standard'));
    var sep = String(this.getParam('separator', ';'));
    var header = Boolean(this.getParam('header', true));
    var func = void 0;
    if (format === 'strict') {
        func = strict;
    } else {
        func = _csvString2.default.stringify;
    }
    if (this.isLast()) {
        feed.close();
    } else if (this.isFirst() && header) {
        feed.write(func(Object.keys(data), sep));
        feed.send(func(data, sep));
    } else {
        feed.send(func(data, sep));
    }
}

/**
 * Take `Object` and transform row  into string
 * where each field is separated with a character
 *
 * @name CSVString
 * @param {String} [format=standard] if set to "strict" the fields will wrapped with double quote
 * @param {String} [separator=;] to indicate the CSV separator
 * @param {Boolean} [header=true] first line contains key name
 * @returns {String}
 */
exports.default = {
    CSVString: CSVString
};