'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _ezs = require('ezs');

var _ezs2 = _interopRequireDefault(_ezs);

var _tmpFilepath = require('tmp-filepath');

var _tmpFilepath2 = _interopRequireDefault(_tmpFilepath);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function OBJStandardize(data, feed) {
    var self = this;
    if (!self.tmpFile) {
        self.tmpFile = (0, _tmpFilepath2.default)('.bin');
        self.struct = [];
        self.tmpInput = _ezs2.default.createStream(_ezs2.default.objectMode());
        self.tmpStream = self.tmpInput.pipe((0, _ezs2.default)('pack')).pipe(_ezs2.default.toBuffer()).pipe(_ezs2.default.compress()).pipe(_fs2.default.createWriteStream(self.tmpFile));
        self.tmpHandle = new Promise(function (resolve, reject) {
            return self.tmpStream.on('error', reject).on('close', resolve);
        });
    }

    if (self.isLast()) {
        self.tmpInput.end();
        self.tmpHandle.then(function () {
            _fs2.default.createReadStream(self.tmpFile).pipe(_ezs2.default.uncompress()).pipe((0, _ezs2.default)('unpack')).on('error', function (e) {
                throw e;
            }).on('data', function (d) {
                var vv = {};
                self.struct.forEach(function (k) {
                    if (!d[k]) {
                        vv[k] = '';
                    } else {
                        vv[k] = d[k];
                    }
                });
                feed.write(vv);
            }).on('end', function () {
                _fs2.default.unlink(self.tmpFile, function () {
                    return feed.close();
                });
            });
        });
    } else {
        Object.keys(data).forEach(function (k) {
            if (self.struct.indexOf(k) === -1) {
                self.struct.push(k);
            }
        });
        (0, _utils.writeTo)(self.tmpInput, data, function () {
            return feed.end();
        });
    }
}

/**
 * Take `Object` and standardize it so each object will have the sames keys
 *
 * @name OBJStandardize
 * @alias standardize
 * @param {undefined} none
 * @returns {Object}
 */
exports.default = {
    OBJStandardize: OBJStandardize
};