'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _url = require('url');

var _fetchWithProxy = require('fetch-with-proxy');

var _fetchWithProxy2 = _interopRequireDefault(_fetchWithProxy);

var _JSONStream = require('JSONStream');

var _JSONStream2 = _interopRequireDefault(_JSONStream);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function URLStream(data, feed) {
    if (this.isLast()) {
        return feed.close();
    }

    var url = this.getParam('url');
    var path = this.getParam('path', '*');
    var cURL = new _url.URL(url);
    cURL.search = new _url.URLSearchParams(data);

    (0, _fetchWithProxy2.default)(cURL.href).then(function (response) {
        if (response.status !== 200) {
            var msg = 'Received status code ' + response.statusCode + ' (' + response.statusMessage + ')\'';
            throw new Error(msg);
        }
        return response.body;
    }).then(function (body) {
        if (path) {
            return body.pipe(_JSONStream2.default.parse(path));
        }
        return body;
    }).then(function (stream) {
        stream.on('data', function (chunk) {
            return feed.write(chunk);
        });
        stream.on('error', function (error) {
            return feed.stop(error);
        });
        stream.on('end', function () {
            return feed.close();
        });
        return stream;
    }).catch(function (error) {
        return feed.stop(error);
    });
}

/**
 * Take `Object` as parameters of URL, throw each chunk from the result
 *
 * @name URLStream
 * @param {String} [url] URL to fecth
 * @param {String} [target] choose the key to set
 * @param {String} [json=false] Pasre as JSON the content of URL
 * @returns {Object}
 */
exports.default = {
    URLStream: URLStream
};